summaryrefslogtreecommitdiff
path: root/dbaccess
diff options
context:
space:
mode:
authorDaniel Herde <daniel@dher.de>2012-08-09 18:25:53 +0200
committerMichael Meeks <michael.meeks@suse.com>2012-08-09 20:46:17 +0100
commitb803fa2579256979bac83f0b193f2c30d524d76b (patch)
treeedf0affac1b4085956ba4df1d8481f238d560a12 /dbaccess
parent21d7f4b4bba79558de830d9e815e127f67274355 (diff)
translated the german comments in a bunch of source files in dbaccess/source
Change-Id: I2d4b10d96668502a4fe84af70d43bd3abaa5ed23
Diffstat (limited to 'dbaccess')
-rw-r--r--dbaccess/source/ui/control/marktree.cxx4
-rw-r--r--dbaccess/source/ui/control/sqledit.cxx11
-rw-r--r--dbaccess/source/ui/dlg/TextConnectionHelper.cxx14
-rw-r--r--dbaccess/source/ui/dlg/adtabdlg.cxx4
-rw-r--r--dbaccess/source/ui/dlg/dbfindex.cxx28
-rw-r--r--dbaccess/source/ui/dlg/queryfilter.cxx10
-rw-r--r--dbaccess/source/ui/dlg/queryorder.cxx2
7 files changed, 36 insertions, 37 deletions
diff --git a/dbaccess/source/ui/control/marktree.cxx b/dbaccess/source/ui/control/marktree.cxx
index e1b17b04c4aa..830f1381ec73 100644
--- a/dbaccess/source/ui/control/marktree.cxx
+++ b/dbaccess/source/ui/control/marktree.cxx
@@ -193,7 +193,7 @@ void OMarkableTreeListBox::CheckButtonHdl()
void OMarkableTreeListBox::checkedButton_noBroadcast(SvLBoxEntry* _pEntry)
{
SvButtonState eState = GetCheckButtonState( _pEntry);
- if (GetModel()->HasChildren(_pEntry)) // Falls Kinder, dann diese auch checken
+ if (GetModel()->HasChildren(_pEntry)) // if it has children, check those too
{
SvLBoxEntry* pChildEntry = GetModel()->Next(_pEntry);
SvLBoxEntry* pSiblingEntry = GetModel()->NextSibling(_pEntry);
@@ -208,7 +208,7 @@ void OMarkableTreeListBox::checkedButton_noBroadcast(SvLBoxEntry* _pEntry)
while(pEntry)
{
SetCheckButtonState(pEntry,eState);
- if(GetModel()->HasChildren(pEntry)) // Falls Kinder, dann diese auch checken
+ if(GetModel()->HasChildren(pEntry)) // if it has children, check those too
{
SvLBoxEntry* pChildEntry = GetModel()->Next(pEntry);
SvLBoxEntry* pSiblingEntry = GetModel()->NextSibling(pEntry);
diff --git a/dbaccess/source/ui/control/sqledit.cxx b/dbaccess/source/ui/control/sqledit.cxx
index 0ce5c2b24196..289960a3e95c 100644
--- a/dbaccess/source/ui/control/sqledit.cxx
+++ b/dbaccess/source/ui/control/sqledit.cxx
@@ -134,7 +134,7 @@ void OSqlEdit::KeyInput( const KeyEvent& rKEvt )
rController.InvalidateFeature(SID_CUT);
rController.InvalidateFeature(SID_COPY);
- // Ist dies ein Cut, Copy, Paste Event?
+ // Is this a cut, copy, paste event?
KeyFuncType aKeyFunc = rKEvt.GetKeyCode().GetFunction();
if( (aKeyFunc==KEYFUNC_CUT)||(aKeyFunc==KEYFUNC_COPY)||(aKeyFunc==KEYFUNC_PASTE) )
m_bAccelAction = sal_True;
@@ -149,10 +149,9 @@ void OSqlEdit::KeyInput( const KeyEvent& rKEvt )
sal_Bool OSqlEdit::IsInAccelAct()
{
DBG_CHKTHIS(OSqlEdit,NULL);
- // Das Cut, Copy, Paste per Accel. fuehrt neben der Aktion im Edit im View
- // auch die entsprechenden Slots aus. Die Aktionen finden also zweimal statt.
- // Um dies zu verhindern, kann im View beim SlotExec diese Funktion
- // aufgerufen werden.
+ // Cut, Copy, Paste by Accel. runs the action in the Edit but also the
+ // corresponding slot in the View. Therefore, the action occurs twice.
+ // To prevent this, SlotExec in View can call this function.
return m_bAccelAction;
}
@@ -220,7 +219,7 @@ void OSqlEdit::SetText(const String& rNewText)
{
DBG_CHKTHIS(OSqlEdit,NULL);
if (m_timerUndoActionCreation.IsActive())
- { // die noch anstehenden Undo-Action erzeugen
+ { // create the trailing undo-actions
m_timerUndoActionCreation.Stop();
LINK(this, OSqlEdit, OnUndoActionTimer).Call(NULL);
}
diff --git a/dbaccess/source/ui/dlg/TextConnectionHelper.cxx b/dbaccess/source/ui/dlg/TextConnectionHelper.cxx
index ab4b1505aac0..d057f1332efa 100644
--- a/dbaccess/source/ui/dlg/TextConnectionHelper.cxx
+++ b/dbaccess/source/ui/dlg/TextConnectionHelper.cxx
@@ -320,47 +320,47 @@ DBG_NAME(OTextConnectionHelper)
Control* pErrorWin = NULL;
String aDelText(m_aFieldSeparator.GetText());
if(!aDelText.Len())
- { // Kein FeldTrenner
+ { // No FieldSeparator
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MISSING));
aErrorText.SearchAndReplaceAscii("#1",m_aFieldSeparatorLabel.GetText());
pErrorWin = &m_aFieldSeparator;
}
else if (!m_aDecimalSeparator.GetText().Len())
- { // kein Decimaltrenner
+ { // No DecimalSeparator
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MISSING));
aErrorText.SearchAndReplaceAscii("#1",m_aDecimalSeparatorLabel.GetText());
pErrorWin = &m_aDecimalSeparator;
}
else if (m_aTextSeparator.GetText() == m_aFieldSeparator.GetText())
- { // Feld und TextTrenner duerfen nicht gleich sein
+ { // Field and TextSeparator must not be the same
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MUST_DIFFER));
aErrorText.SearchAndReplaceAscii("#1",m_aTextSeparatorLabel.GetText());
aErrorText.SearchAndReplaceAscii("#2",m_aFieldSeparatorLabel.GetText());
pErrorWin = &m_aTextSeparator;
}
else if (m_aDecimalSeparator.GetText() == m_aThousandsSeparator.GetText())
- { // Tausender und DecimalTrenner duerfen nicht gleich sein
+ { // Thousands and DecimalSeparator must not be the same
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MUST_DIFFER));
aErrorText.SearchAndReplaceAscii("#1",m_aDecimalSeparatorLabel.GetText());
aErrorText.SearchAndReplaceAscii("#2",m_aThousandsSeparatorLabel.GetText());
pErrorWin = &m_aDecimalSeparator;
}
else if (m_aFieldSeparator.GetText() == m_aThousandsSeparator.GetText())
- { // Tausender und FeldTrenner duerfen nicht gleich sein
+ { // Thousands and FieldSeparator must not be the same
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MUST_DIFFER));
aErrorText.SearchAndReplaceAscii("#1",m_aFieldSeparatorLabel.GetText());
aErrorText.SearchAndReplaceAscii("#2",m_aThousandsSeparatorLabel.GetText());
pErrorWin = &m_aFieldSeparator;
}
else if (m_aFieldSeparator.GetText() == m_aDecimalSeparator.GetText())
- { // Zehner und FeldTrenner duerfen nicht gleich sein
+ { // Tenner and FieldSeparator must not be the same
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MUST_DIFFER));
aErrorText.SearchAndReplaceAscii("#1",m_aFieldSeparatorLabel.GetText());
aErrorText.SearchAndReplaceAscii("#2",m_aDecimalSeparatorLabel.GetText());
pErrorWin = &m_aFieldSeparator;
}
else if (m_aTextSeparator.GetText() == m_aThousandsSeparator.GetText())
- { // Tausender und TextTrenner duerfen nicht gleich sein
+ { // Thousands and TextSeparator must not be the same
aErrorText = String(ModuleRes(STR_AUTODELIMITER_MUST_DIFFER));
aErrorText.SearchAndReplaceAscii("#1",m_aTextSeparatorLabel.GetText());
aErrorText.SearchAndReplaceAscii("#2",m_aThousandsSeparatorLabel.GetText());
diff --git a/dbaccess/source/ui/dlg/adtabdlg.cxx b/dbaccess/source/ui/dlg/adtabdlg.cxx
index f4c4ea9b69ff..10e0836565cb 100644
--- a/dbaccess/source/ui/dlg/adtabdlg.cxx
+++ b/dbaccess/source/ui/dlg/adtabdlg.cxx
@@ -344,8 +344,8 @@ OAddTableDlg::OAddTableDlg( Window* pParent, IAddTableDialogContext& _rContext )
,aHelpButton( this, ModuleRes( PB_HELP ) )
,m_rContext( _rContext )
{
- // der Close-Button hat schon einen Standard-Help-Text, den ich aber hier nicht haben moechte, also den Text ruecksetzen
- // und eine neue ID verteilen
+ // the Close-Button already has a standard help text which should not
+ // occur here. Therefore, resetting the text and giving a new ID
aCloseButton.SetHelpText(String());
aCloseButton.SetHelpId(HID_JOINSH_ADDTAB_CLOSE);
diff --git a/dbaccess/source/ui/dlg/queryfilter.cxx b/dbaccess/source/ui/dlg/queryfilter.cxx
index f8ef52b81740..e4775b4d9af0 100644
--- a/dbaccess/source/ui/dlg/queryfilter.cxx
+++ b/dbaccess/source/ui/dlg/queryfilter.cxx
@@ -103,14 +103,14 @@ DlgFilterCrit::DlgFilterCrit(Window * pParent,
,m_aPredicateInput( _rxORB, _rxConnection, getParseContext() )
{
DBG_CTOR(DlgFilterCrit,NULL);
- // Den String fuer noEntry in die ListBoxen der Feldnamen schreiben
+ // Write the String for noEntry into the ListBoxes of the field names
aLB_WHEREFIELD1.InsertEntry( aSTR_NOENTRY );
aLB_WHEREFIELD2.InsertEntry( aSTR_NOENTRY );
aLB_WHEREFIELD3.InsertEntry( aSTR_NOENTRY );
try
{
- // ... sowie auch die restlichen Felder
+ // ... also write it into the remaining fields
Sequence< ::rtl::OUString> aNames = m_xColumns->getElementNames();
const ::rtl::OUString* pIter = aNames.getConstArray();
const ::rtl::OUString* pEnd = pIter + aNames.getLength();
@@ -590,7 +590,7 @@ void DlgFilterCrit::SelectField( ListBox& rBox, const String& rField )
void DlgFilterCrit::EnableLines()
{
DBG_CHKTHIS(DlgFilterCrit,NULL);
- // Enablen/Disablen ganzer Zeilen
+ // enabling/disabling of whole lines
if( LbPos(aLB_WHEREFIELD1) == 0 )
{
aLB_WHEREFIELD2.Disable();
@@ -631,7 +631,7 @@ void DlgFilterCrit::EnableLines()
aET_WHEREVALUE3.Enable();
}
- // Vergleichsfeld gleich NOENTRY
+ // comparison field equal to NOENTRY
if( LbPos(aLB_WHEREFIELD1) == 0 )
{
aLB_WHERECOMP1.Disable();
@@ -673,7 +673,7 @@ void DlgFilterCrit::EnableLines()
aET_WHEREVALUE3.Enable();
}
- // Vergleichsoperator gleich ISNULL oder ISNOTNULL
+ // comparison operator equal to ISNULL or ISNOTNULL
if(aLB_WHERECOMP1.GetEntryCount() > 2 &&
((LbPos(aLB_WHERECOMP1) == aLB_WHERECOMP1.GetEntryCount()-1) ||
(LbPos(aLB_WHERECOMP1) == aLB_WHERECOMP1.GetEntryCount()-2)) )
diff --git a/dbaccess/source/ui/dlg/queryorder.cxx b/dbaccess/source/ui/dlg/queryorder.cxx
index c817669d9441..fa05721e823c 100644
--- a/dbaccess/source/ui/dlg/queryorder.cxx
+++ b/dbaccess/source/ui/dlg/queryorder.cxx
@@ -103,7 +103,7 @@ DlgOrderCrit::DlgOrderCrit( Window * pParent,
}
try
{
- // ... sowie auch die restlichen Felder
+ // ... also the remaining fields
Sequence< ::rtl::OUString> aNames = m_xColumns->getElementNames();
const ::rtl::OUString* pIter = aNames.getConstArray();
const ::rtl::OUString* pEnd = pIter + aNames.getLength();
diff --git a/dbaccess/source/ui/dlg/dbfindex.cxx b/dbaccess/source/ui/dlg/dbfindex.cxx
index 2d8d4b2434c9..c398ab46bae6 100644
--- a/dbaccess/source/ui/dlg/dbfindex.cxx
+++ b/dbaccess/source/ui/dlg/dbfindex.cxx
@@ -301,10 +301,10 @@ void ODbaseIndexDialog::Init()
aIB_RemoveAll.Disable();
///////////////////////////////////////////////////////////////////////////
- // Alle Indizes werden erst einmal zur Liste der freien Indizes hinzugefuegt.
- // Dann wird fuer jede Tabelle in der Inf-Datei nachgeschaut, welche Indizes sie besitzt.
- // Diese Indizes werden aus der Liste der freien Indizes entfernt
- // und in die Indexliste der Tabelle eingetragen
+ // All indizes are first added to a list of free indizes.
+ // Afterwards, check the index of each table in the Inf-file.
+ // These indizes are removed from the list of free indizes and
+ // entered in the indexlist of the the table.
///////////////////////////////////////////////////////////////////////////
// if the string does not contain a path, cut the string
@@ -423,13 +423,13 @@ void ODbaseIndexDialog::SetCtrls()
)
aCB_Tables.InsertEntry( aLoop->aTableName );
- // Den ersten Datensatz ins Edit stellen
+ // put the first dataset into Edit
if( m_aTableInfoList.size() )
{
const OTableInfo& rTabInfo = m_aTableInfoList.front();
aCB_Tables.SetText( rTabInfo.aTableName );
- // ListBox der Tabellenindizes aufbauen
+ // build ListBox of the table indizes
for ( ConstTableIndexListIterator aIndex = rTabInfo.aIndexList.begin();
aIndex != rTabInfo.aIndexList.end();
++aIndex
@@ -441,7 +441,7 @@ void ODbaseIndexDialog::SetCtrls()
}
// ListBox freie Indizes
for ( ConstTableIndexListIterator aFree = m_aFreeIndexList.begin();
aFree != m_aFreeIndexList.end();
++aFree
@@ -457,7 +457,7 @@ void ODbaseIndexDialog::SetCtrls()
}
//////////////////////////////////////////////////////////////////////////
-// Klasse OTableInfo
+// Class OTableInfo
//-------------------------------------------------------------------------
void OTableInfo::WriteInfFile( const String& rDSN ) const
{
@@ -477,18 +477,18 @@ void OTableInfo::WriteInfFile( const String& rDSN ) const
Config aInfFile( aTransformer.get(OFileNotation::N_SYSTEM) );
aInfFile.SetGroup( aGroupIdent );
- // Erst einmal alle Tabellenindizes loeschen
+ // first, delete all table indizes
rtl::OString aNDX;
sal_uInt16 nKeyCnt = aInfFile.GetKeyCount();
sal_uInt16 nKey = 0;
while( nKey < nKeyCnt )
{
- // Verweist der Key auf ein Indexfile?...
+ // Does the key point to an index file?...
rtl::OString aKeyName = aInfFile.GetKeyName( nKey );
aNDX = aKeyName.copy(0,3);
- //...wenn ja, Indexfile loeschen, nKey steht dann auf nachfolgendem Key
+ //...if yes, delete index file, nKey is at subsequent key
if (aNDX.equalsL(RTL_CONSTASCII_STRINGPARAM("NDX")))
{
aInfFile.DeleteKey(aKeyName);
@@ -499,7 +499,7 @@ void OTableInfo::WriteInfFile( const String& rDSN ) const
}
- // Jetzt alle gespeicherten Indizes hinzufuegen
+ // now add all saved indizes
sal_uInt16 nPos = 0;
for ( ConstTableIndexListIterator aIndex = aIndexList.begin();
aIndex != aIndexList.end();
@@ -507,7 +507,7 @@ void OTableInfo::WriteInfFile( const String& rDSN ) const
)
{
rtl::OStringBuffer aKeyName(RTL_CONSTASCII_STRINGPARAM("NDX"));
- if( nPos > 0 ) // Erster Index erhaelt keine Ziffer
+ if( nPos > 0 ) // first index contains no number
aKeyName.append(static_cast<sal_Int32>(nPos));
aInfFile.WriteKey(
aKeyName.makeStringAndClear(),
@@ -517,7 +517,7 @@ void OTableInfo::WriteInfFile( const String& rDSN ) const
aInfFile.Flush();
- // Falls nur noch [dbase] in INF-File steht, Datei loeschen
+ // if only [dbase] is left in INF-file, delete file
if(!nPos)
{
try
@@ -441,7 +441,7 @@ void ODbaseIndexDialog::SetCtrls()
}
- // ListBox freie Indizes
+ // ListBox of the free indizes
for ( ConstTableIndexListIterator aFree = m_aFreeIndexList.begin();
aFree != m_aFreeIndexList.end();